@@ -12,6 +12,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
+/* eslint-disable no-unused-vars */
 
 /**
  * The Atto WYSIWG pluggable editor, written for Moodle.
@@ -35,7 +36,8 @@ var CSS = {
         TOOLBAR: 'editor_atto_toolbar',
         WRAPPER: 'editor_atto',
         HIGHLIGHT: 'highlight'
-    };
+    },
+    rangy = window.rangy;
 
 /**
  * The Atto editor for Moodle.
@@ -215,7 +217,8 @@ Y.extend(Editor, Y.Base, {
         }
 
         // Add the toolbar and editable zone to the page.
-        this.textarea.get('parentNode').insert(this._wrapper, this.textarea);
+        this.textarea.get('parentNode').insert(this._wrapper, this.textarea).
+                setAttribute('class', 'editor_atto_wrap');
 
         // Hide the old textarea.
         this.textarea.hide();
@@ -294,7 +297,23 @@ Y.extend(Editor, Y.Base, {
      * @chainable
      */
     setupAutomaticPolling: function() {
-        this._registerEventHandle(this.editor.on(['keyup', 'paste', 'cut'], this.updateOriginal, this));
+        this._registerEventHandle(this.editor.on(['keyup', 'cut'], this.updateOriginal, this));
+        this._registerEventHandle(this.editor.on('paste', this.pasteCleanup, this));
+
+        // Call this.updateOriginal after dropped content has been processed.
+        this._registerEventHandle(this.editor.on('drop', this.updateOriginalDelayed, this));
+
+        return this;
+    },
+
+    /**
+     * Calls updateOriginal on a short timer to allow native event handlers to run first.
+     *
+     * @method updateOriginalDelayed
+     * @chainable
+     */
+    updateOriginalDelayed: function() {
+        Y.soon(Y.bind(this.updateOriginal, this));
 
         return this;
     },
