@@ -28,12 +28,8 @@
 require_once(__DIR__ . '/../../../lib/behat/behat_base.php');
 require_once(__DIR__ . '/../../../lib/behat/behat_field_manager.php');
 
-use Behat\Behat\Context\Step\Given as Given,
-    Behat\Behat\Context\Step\When as When,
-    Behat\Behat\Context\Step\Then as Then,
-    Behat\Gherkin\Node\TableNode as TableNode,
+use Behat\Gherkin\Node\TableNode as TableNode,
     Behat\Gherkin\Node\PyStringNode as PyStringNode,
-    Behat\Mink\Element\NodeElement as NodeElement,
     Behat\Mink\Exception\ExpectationException as ExpectationException,
     Behat\Mink\Exception\ElementNotFoundException as ElementNotFoundException;
 
@@ -58,6 +54,10 @@ class behat_forms extends behat_base {
 
         // Ensures the button is present.
         $buttonnode = $this->find_button($button);
+        // Focus on button to ensure it is in viewport, before pressing it.
+        if ($this->running_javascript()) {
+            $buttonnode->focus();
+        }
         $buttonnode->press();
     }
 
@@ -163,6 +163,20 @@ class behat_forms extends behat_base {
 
     }
 
+    /**
+     * Sets the field to wwwroot plus the given path. Include the first slash.
+     *
+     * @Given /^I set the field "(?P<field_string>(?:[^"]|\\")*)" to local url "(?P<field_path_string>(?:[^"]|\\")*)"$/
+     * @throws ElementNotFoundException Thrown by behat_base::find
+     * @param string $field
+     * @param string $path
+     * @return void
+     */
+    public function i_set_the_field_to_local_url($field, $path) {
+        global $CFG;
+        $this->set_field_value($field, $CFG->wwwroot . $path);
+    }
+
     /**
      * Sets the specified value to the field.
      *
@@ -207,7 +221,7 @@ class behat_forms extends behat_base {
     /**
      * Sets the specified value to the field.
      *
-     * @Given /^I set the field "(?P<field_string>(?:[^"]|\\")*)" to multiline$/
+     * @Given /^I set the field "(?P<field_string>(?:[^"]|\\")*)" to multiline:?$/
      * @throws ElementNotFoundException Thrown by behat_base::find
      * @param string $field
      * @param PyStringNode $value
@@ -227,8 +241,9 @@ class behat_forms extends behat_base {
      * @return void
      */
     public function i_set_the_field_with_xpath_to($fieldxpath, $value) {
-        $fieldNode = $this->find('xpath', $fieldxpath);
-        $field = behat_field_manager::get_form_field($fieldNode, $this->getSession());
+        $fieldnode = $this->find('xpath', $fieldxpath);
+        $this->ensure_node_is_visible($fieldnode);
+        $field = behat_field_manager::get_form_field($fieldnode, $this->getSession());
         $field->set_value($value);
     }
 
@@ -483,9 +498,8 @@ class behat_forms extends behat_base {
      * @Given /^I select "(?P<singleselect_option_string>(?:[^"]|\\")*)" from the "(?P<singleselect_name_string>(?:[^"]|\\")*)" singleselect$/
      */
     public function i_select_from_the_singleselect($option, $singleselect) {
-        $actions = array(
-            new Given('I set the field "' . $this->escape($singleselect) . '" to "' . $this->escape($option) . '"'),
-        );
+
+        $this->execute('behat_forms::i_set_the_field_to', array($this->escape($singleselect), $this->escape($option)));
 
         if (!$this->running_javascript()) {
             // Press button in the specified select container.
@@ -497,11 +511,10 @@ class behat_forms extends behat_base {
                     "or .//select[(./@name='" . $singleselect . "' or ./@id='". $singleselect . "')]" .
                 ")]";
 
-            $actions[] = new Given('I click on "' . get_string('go') . '" "button" in the "' . $containerxpath .
-                '" "xpath_element"');
+            $this->execute('behat_general::i_click_on_in_the',
+                array(get_string('go'), "button", $containerxpath, "xpath_element")
+            );
         }
-
-        return $actions;
     }
 
 }
