@@ -30,6 +30,37 @@ require_once($CFG->libdir . '/externallib.php');
 
 
 class core_externallib_testcase extends advanced_testcase {
+
+    /**
+     * Tests for external_settings class.
+     */
+    public function test_external_settings() {
+
+        $settings = \external_settings::get_instance();
+        $currentraw = $settings->get_raw();
+        $currentfilter = $settings->get_filter();
+        $currentfile = $settings->get_file();
+        $currentfileurl = $settings->get_fileurl();
+
+        $this->assertInstanceOf('external_settings', $settings);
+
+        // Check apis.
+        $settings->set_file('plugin.php');
+        $this->assertEquals('plugin.php', $settings->get_file());
+        $settings->set_filter(false);
+        $this->assertFalse($settings->get_filter());
+        $settings->set_fileurl(false);
+        $this->assertFalse($settings->get_fileurl());
+        $settings->set_raw(true);
+        $this->assertTrue($settings->get_raw());
+
+        // Restore original values.
+        $settings->set_file($currentfile);
+        $settings->set_filter($currentfilter);
+        $settings->set_fileurl($currentfileurl);
+        $settings->set_raw($currentraw);
+    }
+
     public function test_validate_params() {
         $params = array('text'=>'aaa', 'someid'=>'6');
         $description = new external_function_parameters(array('someid' => new external_value(PARAM_INT, 'Some int value'),
@@ -92,8 +123,8 @@ class core_externallib_testcase extends advanced_testcase {
 
         $test = '$$ \pi $$';
         $testformat = FORMAT_MARKDOWN;
-        $correct = array('<span class="nolink"><span class="filter_mathjaxloader_equation"><p>$$ \pi $$</p>
-</span></span>', FORMAT_HTML);
+        $correct = array('<span class="filter_mathjaxloader_equation"><p><span class="nolink">$$ \pi $$</span></p>
+</span>', FORMAT_HTML);
         $this->assertSame(external_format_text($test, $testformat, $context->id, 'core', '', 0), $correct);
 
         // Filters can be opted out from by the developer.
@@ -183,6 +214,7 @@ class core_externallib_testcase extends advanced_testcase {
         $correct = 'ENFR hi there%';
         $this->assertSame($correct, external_format_string($test, $context->id, false, ['filter' => false]));
 
+        $this->assertSame("& < > \" '", format_string("& < > \" '", true, ['escape' => false]));
 
         $settings->set_raw($currentraw);
         $settings->set_filter($currentfilter);
@@ -348,7 +380,7 @@ class core_externallib_testcase extends advanced_testcase {
      * @dataProvider all_external_info_provider
      */
     public function test_all_external_info($f) {
-        $desc = external_function_info($f);
+        $desc = external_api::external_function_info($f);
         $this->assertNotEmpty($desc->name);
         $this->assertNotEmpty($desc->classname);
         $this->assertNotEmpty($desc->methodname);
@@ -358,6 +390,107 @@ class core_externallib_testcase extends advanced_testcase {
             $this->assertInstanceOf('external_description', $desc->returns_desc);
         }
     }
+
+    public function test_validate_courses() {
+        $this->resetAfterTest(true);
+
+        $c1 = $this->getDataGenerator()->create_course();
+        $c2 = $this->getDataGenerator()->create_course();
+        $c3 = $this->getDataGenerator()->create_course();
+        $u1 = $this->getDataGenerator()->create_user();
+        $this->getDataGenerator()->enrol_user($u1->id, $c1->id);
+        $courseids = array($c1->id, $c2->id, $c3->id);
+
+        $this->setAdminUser();
+        list($courses, $warnings) = external_util::validate_courses($courseids);
+        $this->assertEmpty($warnings);
+        $this->assertCount(3, $courses);
+        $this->assertArrayHasKey($c1->id, $courses);
+        $this->assertArrayHasKey($c2->id, $courses);
+        $this->assertArrayHasKey($c3->id, $courses);
+        $this->assertEquals($c1->id, $courses[$c1->id]->id);
+        $this->assertEquals($c2->id, $courses[$c2->id]->id);
+        $this->assertEquals($c3->id, $courses[$c3->id]->id);
+
+        $this->setUser($u1);
+        list($courses, $warnings) = external_util::validate_courses($courseids);
+        $this->assertCount(2, $warnings);
+        $this->assertEquals($c2->id, $warnings[0]['itemid']);
+        $this->assertEquals($c3->id, $warnings[1]['itemid']);
+        $this->assertCount(1, $courses);
+        $this->assertArrayHasKey($c1->id, $courses);
+        $this->assertArrayNotHasKey($c2->id, $courses);
+        $this->assertArrayNotHasKey($c3->id, $courses);
+        $this->assertEquals($c1->id, $courses[$c1->id]->id);
+    }
+
+    /**
+     * Validate courses can re-use an array of prefetched courses.
+     */
+    public function test_validate_courses_prefetch() {
+        $this->resetAfterTest(true);
+
+        $c1 = $this->getDataGenerator()->create_course();
+        $c2 = $this->getDataGenerator()->create_course();
+        $c3 = $this->getDataGenerator()->create_course();
+        $c4 = $this->getDataGenerator()->create_course();
+        $u1 = $this->getDataGenerator()->create_user();
+        $this->getDataGenerator()->enrol_user($u1->id, $c1->id);
+        $this->getDataGenerator()->enrol_user($u1->id, $c2->id);
+
+        $courseids = array($c1->id, $c2->id, $c3->id);
+        $courses = array($c2->id => $c2, $c3->id => $c3, $c4->id => $c4);
+
+        $this->setUser($u1);
+        list($courses, $warnings) = external_util::validate_courses($courseids, $courses);
+        $this->assertCount(2, $courses);
+        $this->assertCount(1, $warnings);
+        $this->assertArrayHasKey($c1->id, $courses);
+        $this->assertSame($c2, $courses[$c2->id]);
+        $this->assertArrayNotHasKey($c3->id, $courses);
+        // The extra course passed is not returned.
+        $this->assertArrayNotHasKey($c4->id, $courses);
+    }
+
+
+    public function test_call_external_function() {
+        global $PAGE, $COURSE;
+
+        $this->resetAfterTest(true);
+
+        // Call some webservice functions and verify they are correctly handling $PAGE and $COURSE.
+        // First test a function that calls validate_context outside a course.
+        $this->setAdminUser();
+        $category = $this->getDataGenerator()->create_category();
+        $params = array(
+            'contextid' => context_coursecat::instance($category->id)->id,
+            'name' => 'aaagrrryyy',
+            'idnumber' => '',
+            'description' => ''
+        );
+        $cohort1 = $this->getDataGenerator()->create_cohort($params);
+        $cohort2 = $this->getDataGenerator()->create_cohort();
+
+        $beforepage = $PAGE;
+        $beforecourse = $COURSE;
+        $params = array('cohortids' => array($cohort1->id, $cohort2->id));
+        $result = external_api::call_external_function('core_cohort_get_cohorts', $params);
+
+        $this->assertSame($beforepage, $PAGE);
+        $this->assertSame($beforecourse, $COURSE);
+
+        // Now test a function that calls validate_context inside a course.
+        $course = $this->getDataGenerator()->create_course();
+
+        $beforepage = $PAGE;
+        $beforecourse = $COURSE;
+        $params = array('courseid' => $course->id, 'options' => array());
+        $result = external_api::call_external_function('core_enrol_get_enrolled_users', $params);
+
+        $this->assertSame($beforepage, $PAGE);
+        $this->assertSame($beforecourse, $COURSE);
+    }
+
 }
 
 /*
