@@ -6,7 +6,6 @@
  * @module moodle-core-dock
  */
 
-
 var LOGNS = 'moodle-core-dock',
     BODY = Y.one(Y.config.doc.body),
     CSS = {
@@ -19,7 +18,6 @@ var LOGNS = 'moodle-core-dock',
         dockeditemcontainer: 'dockeditem_container',
         dockedtitle: 'dockedtitle',      // CSS class added to the item's title in each dock
         activeitem: 'activeitem',        // CSS class added to the active item
-        contentonly: 'content-only',
         dockonload: 'dock_on_load'
     },
     SELECTOR = {
@@ -33,7 +31,7 @@ var LOGNS = 'moodle-core-dock',
     DOCKPANEL,
     TABHEIGHTMANAGER,
     BLOCK,
-    DOCKEDITEM;
+    DOCKEDITEM; // eslint-disable-line no-unused-vars
 
 M.core = M.core || {};
 M.core.dock = M.core.dock || {};
@@ -63,6 +61,9 @@ M.core.dock._dockableblocks = {};
  */
 M.core.dock.init = function() {
     Y.all(SELECTOR.dockableblock).each(M.core.dock.registerDockableBlock);
+    Y.Global.on(M.core.globalEvents.BLOCK_CONTENT_UPDATED, function(e) {
+        M.core.dock.notifyBlockChange(e.instanceid);
+    }, this);
     BODY.delegate('click', M.core.dock.dockBlock, SELECTOR.blockmoveto);
     BODY.delegate('key', M.core.dock.dockBlock, SELECTOR.blockmoveto, 'enter');
 };
@@ -115,7 +116,7 @@ M.core.dock.dockBlock = function(id) {
         if (typeof id === 'object' && typeof id.getData === 'function' && !id.ancestor('.'+CSS.dock)) {
             id = id.getData('instanceid');
         } else {
-            Y.log('Invalid instanceid given to dockBlockByInstanceID', 'warn', LOADERNAME);
+            Y.log('Invalid instanceid given to dockBlockByInstanceID', 'warn', LOGNS);
             return;
         }
     }
@@ -141,7 +142,8 @@ M.core.dock.fixTitleOrientation = function(title, text) {
         test,
         width,
         height,
-        container;
+        container,
+        verticaldirection = M.util.get_string('thisdirectionvertical', 'langconfig');
     title = Y.one(title);
 
     if (dock.get('orientation') !== 'vertical') {
@@ -152,10 +154,10 @@ M.core.dock.fixTitleOrientation = function(title, text) {
 
     if (Y.UA.ie > 0 && Y.UA.ie < 8) {
         // IE 6/7 can't rotate text so force ver
-        M.str.langconfig.thisdirectionvertical = 'ver';
+        verticaldirection = 'ver';
     }
 
-    switch (M.str.langconfig.thisdirectionvertical) {
+    switch (verticaldirection) {
         case 'ver':
             // Stacked is easy
             return title.set('innerHTML', text.split('').join('<br />'));
@@ -176,7 +178,8 @@ M.core.dock.fixTitleOrientation = function(title, text) {
     }
 
     // We need to fix a font-size - sorry theme designers.
-    test = Y.Node.create('<h2 class="transform-test-heading"><span class="transform-test-node" style="font-size:'+fontsize+';">'+text+'</span></h2>');
+    test = Y.Node.create('<h2 class="transform-test-heading"><span class="transform-test-node" style="font-size:' +
+            fontsize + ';">' + text + '</span></h2>');
     BODY.insert(test, 0);
     width = test.one('span').get('offsetWidth') * 1.2;
     height = test.one('span').get('offsetHeight');
@@ -194,7 +197,7 @@ M.core.dock.fixTitleOrientation = function(title, text) {
     });
 
     // Positioning is different when in RTL mode.
-    if (right_to_left()) {
+    if (window.right_to_left()) {
         title.setStyle('left', width/2 - height);
     } else {
         title.setStyle('right', width/2 - height);
@@ -339,12 +342,12 @@ DOCK.prototype = {
          * Fires after the dock has been changed from hidden to visible.
          * @event dock:shown
          */
-        this.publish('dock:shown', {prefix:'dock'});
+        this.publish('dock:shown', {prefix:'dock', broadcast: 2});
         /**
          * Fired after the dock has been changed from visible to hidden.
          * @event dock:hidden
          */
-        this.publish('dock:hidden', {prefix:'dock'});
+        this.publish('dock:hidden', {prefix:'dock', broadcast: 2});
         /**
          * Fires when an item is added to the dock.
          * @event dock:itemadded
@@ -360,7 +363,7 @@ DOCK.prototype = {
          * This happens after the itemadded and itemremoved events have been called.
          * @event dock:itemschanged
          */
-        this.publish('dock:itemschanged', {prefix:'dock'});
+        this.publish('dock:itemschanged', {prefix:'dock', broadcast: 2});
         /**
          * Fires once when the docks panel is first initialised.
          * @event dock:panelgenerated
@@ -425,7 +428,6 @@ DOCK.prototype = {
         Y.delegate('mouseenter', this.handleEvent, this.get('dockNode'), '.'+CSS.dockedtitle, this, mouseenterargs);
         this.get('dockNode').on('mouseleave', this.handleEvent, this, {cssselector:'#dock', delay:0.5, iscontained:false});
 
-        Y.delegate('click', this.handleReturnToBlock, this.get('dockNode'), SELECTOR.panelmoveto, this);
         Y.delegate('click', this.handleReturnToBlock, this.get('dockNode'), SELECTOR.panelmoveto, this);
         Y.delegate('dock:actionkey', this.handleDockedItemEvent, this.get('dockNode'), '.'+CSS.dockeditem, this);
 
@@ -487,7 +489,7 @@ DOCK.prototype = {
             };
             try {
                 // Run the customisation function
-                customise_dock_for_theme(this);
+                window.customise_dock_for_theme(this);
             } catch (exception) {
                 // Do nothing at the moment.
                 Y.log('Exception while attempting to apply theme customisations.', 'error', LOGNS);
@@ -514,7 +516,9 @@ DOCK.prototype = {
                         warned = true;
                     }
                     // Damn, the've set something.
-                    Y.log('Note for customise_dock_for_theme code: M.core_dock.cfg.'+key+' is now dock.set(\''+key+'\', value)', 'debug', LOGNS);
+                    Y.log('Note for customise_dock_for_theme code: M.core_dock.cfg.' + key +
+                            ' is now dock.set(\'' + key + '\', value)',
+                            'debug', LOGNS);
                     this.set(cfgmap[key], value);
                 }
             }
@@ -530,7 +534,8 @@ DOCK.prototype = {
                         warned = true;
                     }
                     // Damn, they've set something.
-                    Y.log('Note for customise_dock_for_theme code: M.core_dock.css.'+key+' is now CSS.'+key+' = value', 'debug', LOGNS);
+                    Y.log('Note for customise_dock_for_theme code: M.core_dock.css.' + key + ' is now CSS.' + key + ' = value',
+                            'debug', LOGNS);
                     CSS[key] = value;
                 }
             }
@@ -735,78 +740,126 @@ DOCK.prototype = {
             // Do not resize during initial load
             return;
         }
-        var blockregions = [],
-            populatedblockregions = 0,
-            allnewregions = true,
-            showregions = false,
-            i;
+
+        var populatedRegionCount = 0,
+            populatedBlockRegions = [],
+            unpopulatedBlockRegions = [],
+            isMoving = false,
+            populatedLegacyRegions = [],
+            containsLegacyRegions = false,
+            classesToAdd = [],
+            classesToRemove = [];
+
         // First look for understood regions.
         Y.all(SELECTOR.blockregion).each(function(region){
             var regionname = region.getData('blockregion');
             if (region.all('.block').size() > 0) {
-                populatedblockregions++;
-                BODY.addClass('used-region-'+regionname);
-                BODY.removeClass('empty-region-'+regionname);
-                BODY.removeClass('docked-region-'+regionname);
+                populatedBlockRegions.push(regionname);
+                populatedRegionCount++;
             } else if (region.all('.block_dock_placeholder').size() > 0) {
-                // There are no blocks in the region but there are placeholders.
-                // All blocks in this region have been docked.
-                BODY.addClass('empty-region-'+regionname);
-                BODY.addClass('docked-region-'+regionname);
-                BODY.removeClass('used-region-'+regionname);
+                unpopulatedBlockRegions.push(regionname);
             }
         });
+
         // Next check for legacy regions.
         Y.all('.block-region').each(function(region){
             if (region.test(SELECTOR.blockregion)) {
                 // This is a new region, we've already processed it.
                 return;
             }
-            var hasblocks = (region.all('.block').size() > 0);
+
+            // Sigh - there are legacy regions.
+            containsLegacyRegions = true;
+
+            var regionname = region.get('id').replace(/^region\-/, 'side-'),
+                hasblocks = (region.all('.block').size() > 0);
+
             if (hasblocks) {
-                populatedblockregions++;
+                populatedLegacyRegions.push(regionname);
+                populatedRegionCount++;
+            } else {
+                // This legacy region has no blocks so cannot have the -only body tag.
+                classesToRemove.push(
+                        regionname + '-only'
+                    );
             }
-            allnewregions = false;
-            blockregions[region.get('id')] = {
-                hasblocks : hasblocks,
-                bodyclass : region.get('id').replace(/^region\-/, 'side-')+'-only'
-            };
         });
+
         if (BODY.hasClass('blocks-moving')) {
-            // open up blocks during blocks positioning
-            showregions = true;
-        }
-        if (populatedblockregions === 0 && showregions === false) {
-            BODY.addClass(CSS.contentonly);
-        } else {
-            BODY.removeClass(CSS.contentonly);
+            // When we're moving blocks, we do not want to collapse.
+            isMoving = true;
         }
 
-        if (!allnewregions) {
-            if (populatedblockregions === 0 && showregions === false) {
-                for (i in blockregions) {
-                    if (blockregions[i].bodyclass) {
-                        BODY.removeClass(blockregions[i].bodyclass);
-                    }
-                }
-            } else if (populatedblockregions === 1 && showregions === false) {
-                for (i in blockregions) {
-                    if (blockregions[i].bodyclass) {
-                        if (!blockregions[i].hasblocks) {
-                            BODY.removeClass(blockregions[i].bodyclass);
-                        } else {
-                            BODY.addClass(blockregions[i].bodyclass);
-                        }
-                    }
-                }
+        Y.each(unpopulatedBlockRegions, function(regionname) {
+            classesToAdd.push(
+                    // This block region is empty.
+                    'empty-region-' + regionname,
+
+                    // Which has the same effect as being docked.
+                    'docked-region-' + regionname
+                );
+            classesToRemove.push(
+                    // It is no-longer used.
+                    'used-region-' + regionname,
+
+                    // It cannot be the only region on screen if it is empty.
+                    regionname + '-only'
+                );
+        }, this);
+
+        Y.each(populatedBlockRegions, function(regionname) {
+            classesToAdd.push(
+                    // This block region is in use.
+                    'used-region-' + regionname
+                );
+            classesToRemove.push(
+                    // It is not empty.
+                    'empty-region-' + regionname,
+
+                    // Is it not docked.
+                    'docked-region-' + regionname
+                );
+
+            if (populatedRegionCount === 1 && isMoving === false) {
+                // There was only one populated region, and we are not moving blocks.
+                classesToAdd.push(regionname + '-only');
             } else {
-                for (i in blockregions) {
-                    if (blockregions[i].bodyclass) {
-                        BODY.removeClass(blockregions[i].bodyclass);
-                    }
-                }
+                // There were multiple block regions visible - remove any 'only' classes.
+                classesToRemove.push(regionname + '-only');
+            }
+        }, this);
+
+        if (containsLegacyRegions) {
+            // Handle the classing for legacy blocks. These have slightly different class names for the body.
+            if (isMoving || populatedRegionCount !== 1) {
+                Y.each(populatedLegacyRegions, function(regionname) {
+                    classesToRemove.push(regionname + '-only');
+                });
+            } else {
+                Y.each(populatedLegacyRegions, function(regionname) {
+                    classesToAdd.push(regionname + '-only');
+                });
             }
         }
+
+        if (!BODY.hasClass('has-region-content')) {
+            // This page does not have a content region, therefore content-only is implied when all block regions are docked.
+            if (populatedRegionCount === 0 && isMoving === false) {
+                // If all blocks are docked, ensure that the content-only class is added anyway.
+                classesToAdd.push('content-only');
+            } else {
+                // Otherwise remove it.
+                classesToRemove.push('content-only');
+            }
+        }
+
+        // Modify the body clases.
+        Y.each(classesToRemove, function(className) {
+            BODY.removeClass(className);
+        });
+        Y.each(classesToAdd, function(className) {
+            BODY.addClass(className);
+        });
     },
     /**
      * Adds an item to the dock.
@@ -1096,8 +1149,8 @@ Y.extend(DOCK, Y.Base, DOCK.prototype, {
          * @type String
          * @default t/dock_to_block
          */
-        undockAllIconUrl : {
-            value : M.util.image_url('t/dock_to_block', 'moodle'),
+        undockAllIconUrl: {
+            value : M.util.image_url((window.right_to_left()) ? 't/dock_to_block_rtl' : 't/dock_to_block', 'moodle'),
             validator : Y.Lang.isString
         }
     }
