@@ -17,15 +17,14 @@
 /**
  * Data module version information
  *
- * @package    mod
- * @subpackage data
- * @copyright  2005 onwards Martin Dougiamas  {@link http://moodle.com}
- * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * @package   mod_data
+ * @copyright 2005 onwards Martin Dougiamas  {@link http://moodle.com}
+ * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
 
 defined('MOODLE_INTERNAL') || die();
 
-$module->version   = 2012112900;       // The current module version (Date: YYYYMMDDXX)
-$module->requires  = 2012112900;    // Requires this Moodle version
-$module->component = 'mod_data';       // Full name of the plugin (used for diagnostics)
-$module->cron      = 0;
+$plugin->version   = 2016052300;       // The current module version (Date: YYYYMMDDXX)
+$plugin->requires  = 2016051900;       // Requires this Moodle version
+$plugin->component = 'mod_data';       // Full name of the plugin (used for diagnostics)
+$plugin->cron      = 0;
