@@ -33,9 +33,19 @@ class mod_lesson_mod_form extends moodleform_mod {
 
     protected $course = null;
 
-    public function mod_lesson_mod_form($current, $section, $cm, $course) {
+    public function __construct($current, $section, $cm, $course) {
         $this->course = $course;
-        parent::moodleform_mod($current, $section, $cm, $course);
+        parent::__construct($current, $section, $cm, $course);
+    }
+
+    /**
+     * Old syntax of class constructor. Deprecated in PHP7.
+     *
+     * @deprecated since Moodle 3.1
+     */
+    public function mod_lesson_mod_form($current, $section, $cm, $course) {
+        debugging('Use of class name as constructor is deprecated', DEBUG_DEVELOPER);
+        self::__construct($current, $section, $cm, $course);
     }
 
     function definition() {
@@ -43,39 +53,39 @@ class mod_lesson_mod_form extends moodleform_mod {
 
         $mform    = $this->_form;
 
-        $config = get_config('lesson');
+        $lessonconfig = get_config('mod_lesson');
 
         $mform->addElement('header', 'general', get_string('general', 'form'));
 
         /** Legacy slideshow width element to maintain backwards compatibility */
         $mform->addElement('hidden', 'width');
         $mform->setType('width', PARAM_INT);
-        $mform->setDefault('width', $CFG->lesson_slideshowwidth);
+        $mform->setDefault('width', $lessonconfig->slideshowwidth);
 
         /** Legacy slideshow height element to maintain backwards compatibility */
         $mform->addElement('hidden', 'height');
         $mform->setType('height', PARAM_INT);
-        $mform->setDefault('height', $CFG->lesson_slideshowheight);
+        $mform->setDefault('height', $lessonconfig->slideshowheight);
 
         /** Legacy slideshow background color element to maintain backwards compatibility */
         $mform->addElement('hidden', 'bgcolor');
         $mform->setType('bgcolor', PARAM_TEXT);
-        $mform->setDefault('bgcolor', $CFG->lesson_slideshowbgcolor);
+        $mform->setDefault('bgcolor', $lessonconfig->slideshowbgcolor);
 
         /** Legacy media popup width element to maintain backwards compatibility */
         $mform->addElement('hidden', 'mediawidth');
         $mform->setType('mediawidth', PARAM_INT);
-        $mform->setDefault('mediawidth', $CFG->lesson_mediawidth);
+        $mform->setDefault('mediawidth', $lessonconfig->mediawidth);
 
         /** Legacy media popup height element to maintain backwards compatibility */
         $mform->addElement('hidden', 'mediaheight');
         $mform->setType('mediaheight', PARAM_INT);
-        $mform->setDefault('mediaheight', $CFG->lesson_mediaheight);
+        $mform->setDefault('mediaheight', $lessonconfig->mediaheight);
 
         /** Legacy media popup close button element to maintain backwards compatibility */
         $mform->addElement('hidden', 'mediaclose');
         $mform->setType('mediaclose', PARAM_BOOL);
-        $mform->setDefault('mediaclose', $CFG->lesson_mediaclose);
+        $mform->setDefault('mediaclose', $lessonconfig->mediaclose);
 
         $mform->addElement('text', 'name', get_string('name'), array('size'=>'64'));
         if (!empty($CFG->formatstringstriptags)) {
@@ -98,18 +108,22 @@ class mod_lesson_mod_form extends moodleform_mod {
 
         $mform->addElement('filemanager', 'mediafile', get_string('mediafile', 'lesson'), null, $filemanageroptions);
         $mform->addHelpButton('mediafile', 'mediafile', 'lesson');
+        $mform->setAdvanced('mediafile', $lessonconfig->mediafile_adv);
 
         $mform->addElement('selectyesno', 'progressbar', get_string('progressbar', 'lesson'));
         $mform->addHelpButton('progressbar', 'progressbar', 'lesson');
-        $mform->setDefault('progressbar', 0);
+        $mform->setDefault('progressbar', $lessonconfig->progressbar);
+        $mform->setAdvanced('progressbar', $lessonconfig->progressbar_adv);
 
         $mform->addElement('selectyesno', 'ongoing', get_string('ongoing', 'lesson'));
         $mform->addHelpButton('ongoing', 'ongoing', 'lesson');
-        $mform->setDefault('ongoing', 0);
+        $mform->setDefault('ongoing', $lessonconfig->ongoing);
+        $mform->setAdvanced('ongoing', $lessonconfig->ongoing_adv);
 
         $mform->addElement('selectyesno', 'displayleft', get_string('displayleftmenu', 'lesson'));
         $mform->addHelpButton('displayleft', 'displayleftmenu', 'lesson');
-        $mform->setDefault('displayleft', 0);
+        $mform->setDefault('displayleft', $lessonconfig->displayleftmenu);
+        $mform->setAdvanced('displayleft', $lessonconfig->displayleftmenu_adv);
 
         $options = array();
         for($i = 100; $i >= 0; $i--) {
@@ -117,11 +131,13 @@ class mod_lesson_mod_form extends moodleform_mod {
         }
         $mform->addElement('select', 'displayleftif', get_string('displayleftif', 'lesson'), $options);
         $mform->addHelpButton('displayleftif', 'displayleftif', 'lesson');
-        $mform->setDefault('displayleftif', 0);
+        $mform->setDefault('displayleftif', $lessonconfig->displayleftif);
+        $mform->setAdvanced('displayleftif', $lessonconfig->displayleftif_adv);
 
         $mform->addElement('selectyesno', 'slideshow', get_string('slideshow', 'lesson'));
         $mform->addHelpButton('slideshow', 'slideshow', 'lesson');
-        $mform->setDefault('slideshow', 0);
+        $mform->setDefault('slideshow', $lessonconfig->slideshow);
+        $mform->setAdvanced('slideshow', $lessonconfig->slideshow_adv);
 
         $numbers = array();
         for ($i = 20; $i > 1; $i--) {
@@ -129,13 +145,15 @@ class mod_lesson_mod_form extends moodleform_mod {
         }
 
         $mform->addElement('select', 'maxanswers', get_string('maximumnumberofanswersbranches', 'lesson'), $numbers);
-        $mform->setDefault('maxanswers', $CFG->lesson_maxanswers);
+        $mform->setDefault('maxanswers', $lessonconfig->maxanswers);
+        $mform->setAdvanced('maxanswers', $lessonconfig->maxanswers_adv);
         $mform->setType('maxanswers', PARAM_INT);
         $mform->addHelpButton('maxanswers', 'maximumnumberofanswersbranches', 'lesson');
 
         $mform->addElement('selectyesno', 'feedback', get_string('displaydefaultfeedback', 'lesson'));
         $mform->addHelpButton('feedback', 'displaydefaultfeedback', 'lesson');
-        $mform->setDefault('feedback', 0);
+        $mform->setDefault('feedback', $lessonconfig->defaultfeedback);
+        $mform->setAdvanced('feedback', $lessonconfig->defaultfeedback_adv);
 
         // Get the modules.
         if ($mods = get_course_mods($COURSE->id)) {
@@ -155,6 +173,7 @@ class mod_lesson_mod_form extends moodleform_mod {
             $mform->addElement('select', 'activitylink', get_string('activitylink', 'lesson'), $modinstances);
             $mform->addHelpButton('activitylink', 'activitylink', 'lesson');
             $mform->setDefault('activitylink', 0);
+            $mform->setAdvanced('activitylink', $lessonconfig->activitylink_adv);
         }
 
         // Availability.
@@ -170,13 +189,17 @@ class mod_lesson_mod_form extends moodleform_mod {
         $mform->addElement('duration', 'timelimit', get_string('timelimit', 'lesson'),
                 array('optional' => true));
         $mform->addHelpButton('timelimit', 'timelimit', 'lesson');
+        $mform->setAdvanced('timelimit', $lessonconfig->timelimit_adv);
+        $mform->setDefault('timelimit', $lessonconfig->timelimit);
 
         $mform->addElement('selectyesno', 'usepassword', get_string('usepassword', 'lesson'));
         $mform->addHelpButton('usepassword', 'usepassword', 'lesson');
-        $mform->setDefault('usepassword', 0);
+        $mform->setDefault('usepassword', $lessonconfig->password);
+        $mform->setAdvanced('usepassword', $lessonconfig->password_adv);
 
         $mform->addElement('passwordunmask', 'password', get_string('password', 'lesson'));
         $mform->setDefault('password', '');
+        $mform->setAdvanced('password', $lessonconfig->password_adv);
         $mform->setType('password', PARAM_RAW);
         $mform->disabledIf('password', 'usepassword', 'eq', 0);
         $mform->disabledIf('passwordunmask', 'usepassword', 'eq', 0);
@@ -231,11 +254,13 @@ class mod_lesson_mod_form extends moodleform_mod {
 
         $mform->addElement('selectyesno', 'modattempts', get_string('modattempts', 'lesson'));
         $mform->addHelpButton('modattempts', 'modattempts', 'lesson');
-        $mform->setDefault('modattempts', 0);
+        $mform->setDefault('modattempts', $lessonconfig->modattempts);
+        $mform->setAdvanced('modattempts', $lessonconfig->modattempts_adv);
 
         $mform->addElement('selectyesno', 'review', get_string('displayreview', 'lesson'));
         $mform->addHelpButton('review', 'displayreview', 'lesson');
-        $mform->setDefault('review', 0);
+        $mform->setDefault('review', $lessonconfig->displayreview);
+        $mform->setAdvanced('review', $lessonconfig->displayreview_adv);
 
         $numbers = array();
         for ($i = 10; $i > 0; $i--) {
@@ -243,7 +268,8 @@ class mod_lesson_mod_form extends moodleform_mod {
         }
         $mform->addElement('select', 'maxattempts', get_string('maximumnumberofattempts', 'lesson'), $numbers);
         $mform->addHelpButton('maxattempts', 'maximumnumberofattempts', 'lesson');
-        $mform->setDefault('maxattempts', 1);
+        $mform->setDefault('maxattempts', $lessonconfig->maximumnumberofattempts);
+        $mform->setAdvanced('maxattempts', $lessonconfig->maximumnumberofattempts_adv);
 
         $defaultnextpages = array();
         $defaultnextpages[0] = get_string('normal', 'lesson');
@@ -251,7 +277,8 @@ class mod_lesson_mod_form extends moodleform_mod {
         $defaultnextpages[LESSON_UNANSWEREDPAGE] = get_string('showanunansweredpage', 'lesson');
         $mform->addElement('select', 'nextpagedefault', get_string('actionaftercorrectanswer', 'lesson'), $defaultnextpages);
         $mform->addHelpButton('nextpagedefault', 'actionaftercorrectanswer', 'lesson');
-        $mform->setDefault('nextpagedefault', $CFG->lesson_defaultnextpage);
+        $mform->setDefault('nextpagedefault', $lessonconfig->defaultnextpage);
+        $mform->setAdvanced('nextpagedefault', $lessonconfig->defaultnextpage_adv);
 
         $numbers = array();
         for ($i = 100; $i >= 0; $i--) {
@@ -259,7 +286,8 @@ class mod_lesson_mod_form extends moodleform_mod {
         }
         $mform->addElement('select', 'maxpages', get_string('numberofpagestoshow', 'lesson'), $numbers);
         $mform->addHelpButton('maxpages', 'numberofpagestoshow', 'lesson');
-        $mform->setDefault('maxpages', 0);
+        $mform->setDefault('maxpages', $lessonconfig->numberofpagestoshow);
+        $mform->setAdvanced('maxpages', $lessonconfig->numberofpagestoshow_adv);
 
         // Grade.
         $this->standard_grading_coursemodule_elements();
@@ -268,22 +296,26 @@ class mod_lesson_mod_form extends moodleform_mod {
 
         $mform->addElement('selectyesno', 'practice', get_string('practice', 'lesson'));
         $mform->addHelpButton('practice', 'practice', 'lesson');
-        $mform->setDefault('practice', 0);
+        $mform->setDefault('practice', $lessonconfig->practice);
+        $mform->setAdvanced('practice', $lessonconfig->practice_adv);
 
         $mform->addElement('selectyesno', 'custom', get_string('customscoring', 'lesson'));
         $mform->addHelpButton('custom', 'customscoring', 'lesson');
-        $mform->setDefault('custom', 1);
+        $mform->setDefault('custom', $lessonconfig->customscoring);
+        $mform->setAdvanced('custom', $lessonconfig->customscoring_adv);
 
         $mform->addElement('selectyesno', 'retake', get_string('retakesallowed', 'lesson'));
         $mform->addHelpButton('retake', 'retakesallowed', 'lesson');
-        $mform->setDefault('retake', 0);
+        $mform->setDefault('retake', $lessonconfig->retakesallowed);
+        $mform->setAdvanced('retake', $lessonconfig->retakesallowed_adv);
 
         $options = array();
         $options[0] = get_string('usemean', 'lesson');
         $options[1] = get_string('usemaximum', 'lesson');
         $mform->addElement('select', 'usemaxgrade', get_string('handlingofretakes', 'lesson'), $options);
         $mform->addHelpButton('usemaxgrade', 'handlingofretakes', 'lesson');
-        $mform->setDefault('usemaxgrade', 0);
+        $mform->setDefault('usemaxgrade', $lessonconfig->handlingofretakes);
+        $mform->setAdvanced('usemaxgrade', $lessonconfig->handlingofretakes_adv);
         $mform->disabledIf('usemaxgrade', 'retake', 'eq', '0');
 
         $numbers = array();
@@ -292,7 +324,8 @@ class mod_lesson_mod_form extends moodleform_mod {
         }
         $mform->addElement('select', 'minquestions', get_string('minimumnumberofquestions', 'lesson'), $numbers);
         $mform->addHelpButton('minquestions', 'minimumnumberofquestions', 'lesson');
-        $mform->setDefault('minquestions', 0);
+        $mform->setDefault('minquestions', $lessonconfig->minimumnumberofquestions);
+        $mform->setAdvanced('minquestions', $lessonconfig->minimumnumberofquestions_adv);
 
 //-------------------------------------------------------------------------------
         $this->standard_coursemodule_elements();
@@ -393,6 +426,12 @@ class mod_lesson_mod_form extends moodleform_mod {
                 $data->completiontimespent = 0;
             }
         }
+        if (!empty($data->completionunlocked)) {
+            $autocompletion = !empty($data->completion) && $data->completion == COMPLETION_TRACKING_AUTOMATIC;
+            if (empty($data->completionendreached) || !$autocompletion) {
+                $data->completionendreached = 0;
+            }
+        }
         return $data;
     }
 }
