@@ -30,13 +30,12 @@
 //
 // BasicLTI4Moodle is copyright 2009 by Marc Alier Forment, Jordi Piguillem and Nikolas Galanis
 // of the Universitat Politecnica de Catalunya http://www.upc.edu
-// Contact info: Marc Alier Forment granludo @ gmail.com or marc.alier @ upc.edu
+// Contact info: Marc Alier Forment granludo @ gmail.com or marc.alier @ upc.edu.
 
 /**
  * This file contains en_utf8 translation of the Basic LTI module
  *
- * @package    mod
- * @subpackage lti
+ * @package mod_lti
  * @copyright  2009 Marc Alier, Jordi Piguillem, Nikolas Galanis
  *  marc.alier@upc.edu
  * @copyright  2009 Universitat Politecnica de Catalunya http://www.upc.edu
@@ -50,81 +49,95 @@
 defined('MOODLE_INTERNAL') || die;
 
 $string['accept'] = 'Accept';
+$string['accepted'] = 'Accepted';
 $string['accept_grades'] = 'Accept grades from the tool';
 $string['accept_grades_admin'] = 'Accept grades from the tool';
-$string['accept_grades_admin_help'] = 'Specify whether the tool provider can add, update, read, and delete grades associated with instances of this tool type.
+$string['accept_grades_admin_help'] = 'Specify whether the tool provider can add, update, read, and delete grades associated with instances of this tool.
 
 Some tool providers support reporting grades back to Moodle based on actions taken within the tool, creating a more integrated
 experience.';
 $string['accept_grades_help'] = 'Specify whether the tool provider can add, update, read, and delete grades associated only with this external tool instance.
 
-Some tool providers support reporting grades back to Moodle based on actions taken within the tool, creating a more integrated
-experience.
+Some tool providers support reporting grades back to Moodle based on actions taken within the tool, creating a more integrated experience.
 
-Note that this setting may be overriden in the tool configuration.';
+Note that this setting may be overridden in the tool configuration.';
 $string['action'] = 'Action';
+$string['activate'] = 'Activate';
+$string['activatetoadddescription'] = 'You will need to activate this tool before you can add a description.';
 $string['active'] = 'Active';
 $string['activity'] = 'Activity';
-$string['addnewapp'] = 'Enable External Application';
+$string['addnewapp'] = 'Enable external application';
 $string['addserver'] = 'Add new trusted server';
-$string['addtype'] = 'Add external tool configuration';
+$string['addtype'] = 'Add preconfigured tool';
 $string['allow'] = 'Allow';
 $string['allowinstructorcustom'] = 'Allow teachers to add custom parameters';
 $string['allowsetting'] = 'Allow tool to store 8K of settings in Moodle';
 $string['always'] = 'Always';
-$string['automatic'] = 'Automatic, based on Launch URL';
-$string['baseurl'] = 'Base URL';
+$string['automatic'] = 'Automatic, based on launch URL';
+$string['autoaddtype'] = 'Add tool';
+$string['baseurl'] = 'Base URL/tool registration name';
 $string['basiclti'] = 'LTI';
-$string['basiclti_base_string'] = 'LTI OAuth Base String';
-$string['basiclti_endpoint'] = 'LTI Launch Endpoint';
+$string['basiclti_base_string'] = 'LTI OAuth base string';
+$string['basiclti_endpoint'] = 'LTI launch endpoint';
 $string['basiclti_in_new_window'] = 'Your activity has opened in a new window';
-$string['basiclti_parameters'] = 'LTI Launch Parameters';
-$string['basicltiactivities'] = 'LTI Activities';
+$string['basiclti_parameters'] = 'LTI launch parameters';
+$string['basicltiactivities'] = 'LTI activities';
 $string['basicltifieldset'] = 'Custom example fieldset';
-$string['basicltiintro'] = 'Activity Description';
-$string['basicltiname'] = 'Activity Name';
-$string['basicltisettings'] = 'Basic Learning Tool Interoperability Settings';
+$string['basicltiintro'] = 'Activity description';
+$string['basicltiname'] = 'Activity name';
+$string['basicltisettings'] = 'Basic Learning Tool Interoperability (LTI) settings';
+$string['cancel'] = 'Cancel';
+$string['cancelled'] = 'Cancelled';
 $string['cannot_delete'] = 'You may not delete this tool configuration.';
 $string['cannot_edit'] = 'You may not edit this tool configuration.';
+$string['capabilities'] = 'Capabilities';
+$string['capabilitiesrequired'] = 'This tool requires access to the following data in order to activate:';
+$string['capabilities_help'] = 'Select those capabilities which you wish to offer to the tool provider.  More than one capability can be selected.';
+$string['click_to_continue'] = '<a href="{$a->link}" target="_top">Click to continue</a>';
 $string['comment'] = 'Comment';
-$string['configpassword'] = 'Default Remote Tool Password';
+$string['configpassword'] = 'Default remote tool password';
 $string['configpreferheight'] = 'Default preferred height';
 $string['configpreferwidget'] = 'Set widget as default launch';
 $string['configpreferwidth'] = 'Default preferred width';
-$string['configresourceurl'] = 'Default Resource URL';
-$string['configtoolurl'] = 'Default Remote Tool URL';
-$string['configtypes'] = 'Enable LTI Applications';
-$string['course_tool_types'] = 'Course tool types';
-$string['courseid'] = 'Course id number';
+$string['configresourceurl'] = 'Default resource URL';
+$string['configtoolurl'] = 'Default remote tool URL';
+$string['configtypes'] = 'Enable LTI applications';
+$string['configured'] = 'Configured';
+$string['confirmtoolactivation'] = 'Are you sure you would like to activate this tool?';
+$string['courseactivitiesorresources'] = 'Course activities or resources';
+$string['course_tool_types'] = 'Course tools';
+$string['courseid'] = 'Course ID number';
+$string['courseinformation'] = 'Course information';
+$string['courselink'] = 'Go to course';
 $string['coursemisconf'] = 'Course is misconfigured';
-$string['createdon'] = 'Created On';
+$string['createdon'] = 'Created on';
 $string['curllibrarymissing'] = 'PHP Curl library must be installed to use LTI';
 $string['custom'] = 'Custom parameters';
 $string['custom_config'] = 'Using custom tool configuration.';
 $string['custom_help'] = 'Custom parameters are settings used by the tool provider. For example, a custom parameter may be used to display
-a specific resource from the provider.
+a specific resource from the provider.  Each parameter should be entered on a separate line using a format of "name=value"; for example, "chapter=3".
 
 It is safe to leave this field unchanged unless directed by the tool provider.';
 $string['custominstr'] = 'Custom parameters';
-$string['debuglaunch'] = 'Debug Option';
+$string['debuglaunch'] = 'Debug option';
 $string['debuglaunchoff'] = 'Normal launch';
 $string['debuglaunchon'] = 'Debug launch';
 $string['default'] = 'Default';
-$string['default_launch_container'] = 'Default Launch Container';
+$string['default_launch_container'] = 'Default launch container';
 $string['default_launch_container_help'] = 'The launch container affects the display of the tool when launched from the course. Some launch containers provide more screen
-real estate to the tool, and others provide a more integrated feel with the Moodle environemnt.
+real estate to the tool, and others provide a more integrated feel with the Moodle environment.
 
 * **Default** - Use the launch container specified by the tool configuration.
 * **Embed** - The tool is displayed within the existing Moodle window, in a manner similar to most other Activity types.
-* **Embed, without blocks** - The tool is displayed within the existing Moodle window, with just the neavigation controls
+* **Embed, without blocks** - The tool is displayed within the existing Moodle window, with just the navigation controls
         at the top of the page.
 * **New window** - The tool opens in a new window, occupying all the available space.
         Depending on the browser, it will open in a new tab or a popup window.
         It is possible that browsers will prevent the new window from opening.';
-$string['delegate'] = 'Delegate to Teacher';
+$string['delegate'] = 'Delegate to teacher';
 $string['delete'] = 'Delete';
-$string['delete_confirmation'] = 'Are you sure you want to delete this external tool configuration?';
-$string['deletetype'] = 'Delete external tool configuration';
+$string['delete_confirmation'] = 'Are you sure you want to delete this preconfigured tool?';
+$string['deletetype'] = 'Delete preconfigured tool';
 $string['display_description'] = 'Display activity description when launched';
 $string['display_description_help'] = 'If selected, the activity description (specified above) will display above the tool provider\'s content.
 
@@ -142,14 +155,19 @@ $string['domain_mismatch'] = 'Launch URL\'s domain does not match tool configura
 $string['donot'] = 'Do not send';
 $string['donotaccept'] = 'Do not accept';
 $string['donotallow'] = 'Do not allow';
-$string['edittype'] = 'Edit external tool configuration';
+$string['duplicateregurl'] = 'This registration URL is already in use';
+$string['editdescription'] = 'Click here to give this tool a description';
+$string['edittype'] = 'Edit preconfigured tool';
 $string['embed'] = 'Embed';
 $string['embed_no_blocks'] = 'Embed, without blocks';
 $string['enableemailnotification'] = 'Send notification emails';
 $string['enableemailnotification_help'] = 'If enabled, students will receive email notification when their tool submissions are graded.';
+$string['enterkeyandsecret'] = 'Enter your consumer key and shared secret';
+$string['errorbadurl'] = 'URL is not a valid tool URL or cartridge.';
 $string['errormisconfig'] = 'Misconfigured tool. Please ask your Moodle administrator to fix the configuration of the tool.';
-$string['extensions'] = 'LTI Extension Services';
-$string['external_tool_type'] = 'External tool type';
+$string['existing_window'] = 'Existing window';
+$string['extensions'] = 'LTI extension services';
+$string['external_tool_type'] = 'Preconfigured tool';
 $string['external_tool_type_help'] = 'The main purpose of a tool configuration is to set up a secure communication channel between Moodle and the tool provider.
 It also provides an opportunity for configuration defaults and setting up additional services provided by the tool.
 
@@ -157,30 +175,32 @@ It also provides an opportunity for configuration defaults and setting up additi
        based on the Launch URL. Tools configured by both an administrator or within this course will be used.
        When the Launch URL is specified, Moodle will provide feedback on whether it recognizes it or not. If Moodle does not recognize the Launch URL,
        you may need to enter the tool configuration details manually.
-* **A specific tool type** - By selecting a specific tool type, you can force Moodle to use that tool configuration when communicating with the
+* **A specific preconfigured tool** - By selecting a preconfigured tool, you can force Moodle to use that tool configuration when communicating with the
        external tool provider. If the Launch URL does not appear to belong to the tool provider, a warning will appear. In some cases, it is not necessary
-       to enter a Launch URL when providing a specific tool type (if not launching to a particular resource within the tool provider).
+       to enter a Launch URL when providing a specific preconfigured tool (if not launching to a particular resource within the tool provider).
 * **Custom configuration** - To setup custom tool configuration on just this instance, show Advanced options, and enter the consumer key and
        shared secret yourself. If you do not have a consumer key and shared secret, you may be able to request them from the tool provider.
        Not all tools require a consumer key and shared secret, in which case the fields may be left blank.
 
-### Tool type editing
+### Preconfigured tool editing
 
-Three icons are available after the External tool type dropdown list:
+Three icons are available after the preconfigured tool dropdown list:
 
 * **Add** - Create a course level tool configuration. All External Tool instances in this course may use the tool configuration.
-* **Edit** - Select a course level tool type from the dropdown, then click this icon. The details of the tool configuration may be edited.
-* **Delete** - Remove the selected course level tool type.';
-$string['external_tool_types'] = 'External Tool Types';
+* **Edit** - Select a course level tool from the dropdown, then click this icon. The details of the tool configuration may be edited.
+* **Delete** - Remove the selected course level tool.';
+$string['external_tool_types'] = 'Preconfigured tools';
 $string['failedtoconnect'] = 'Moodle was unable to communicate with the "{$a}" system';
+$string['failedtocreatetooltype'] = 'Failed to create new tool. Please check the URL and try again.';
+$string['failedtodeletetoolproxy'] = 'Failed to delete tool registration. You may need to visit "Manage external tool registrations" and delete it manually.';
 $string['filter_basiclti_configlink'] = 'Configure your preferred sites and their passwords';
 $string['filter_basiclti_password'] = 'Password is mandatory';
 $string['filterconfig'] = 'LTI administration';
 $string['filtername'] = 'LTI';
 $string['fixexistingconf'] = 'Use an existing configuration for the misconfigured instance';
-$string['fixnew'] = 'New Configuration';
+$string['fixnew'] = 'New configuration';
 $string['fixnewconf'] = 'Define a new configuration for the misconfigured instance';
-$string['fixold'] = 'Use Existing';
+$string['fixold'] = 'Use existing';
 $string['forced_help'] = 'This setting has been forced in a course or site level tool configuration. You may not change it from this interface.';
 $string['force_ssl'] = 'Force SSL';
 $string['force_ssl_help'] = 'Selecting this option forces all launches to this tool provider to use SSL.
@@ -189,8 +209,8 @@ In addition, all web service requests from the tool provider will use SSL.
 
 If using this option, confirm that this Moodle site and the tool provider support SSL.';
 $string['generaltool'] = 'General tool';
-$string['global_tool_types'] = 'Global tool types';
-$string['grading'] = 'Grade Routing';
+$string['global_tool_types'] = 'Global preconfigured tools';
+$string['grading'] = 'Grade routing';
 $string['icon_url'] = 'Icon URL';
 $string['icon_url_help'] = 'The icon URL allows the icon that shows up in the course listing for this activity to be modified. Instead of using the default
 LTI icon, an icon which conveys the type of activity may be specified.';
@@ -198,24 +218,27 @@ $string['id'] = 'id';
 $string['invalidid'] = 'LTI ID was incorrect';
 $string['launch_in_moodle'] = 'Launch tool in moodle';
 $string['launch_in_popup'] = 'Launch tool in a pop-up';
-$string['launch_url'] = 'Launch URL';
+$string['launch_url'] = 'Launch/cartridge URL';
 $string['launch_url_help'] = 'The Launch URL indicates the web address of the External Tool, and may contain additional information, such as the resource to show.
 If you are unsure what to enter for the Launch URL, please check with the tool provider for more information.
 
-If you have selected a specific tool type, you may not need to enter a Launch URL. If the tool link is used to just launch
+You can also enter a cartridge URL if you have one, and the rest of the form details will fill automatically.
+
+If you have selected a preconfigured tool, you may not need to enter a Launch URL. If the tool link is used to just launch
 into the tool provider\'s system, and not go to a specific resource, this will likely be the case.';
-$string['launchinpopup'] = 'Launch Container';
+$string['launchinpopup'] = 'Launch container';
 $string['launchinpopup_help'] = 'The launch container affects the display of the tool when launched from the course. Some launch containers provide more screen
-real estate to the tool, and others provide a more integrated feel with the Moodle environemnt.
+real estate to the tool, and others provide a more integrated feel with the Moodle environment.
 
 * **Default** - Use the launch container specified by the tool configuration.
 * **Embed** - The tool is displayed within the existing Moodle window, in a manner similar to most other Activity types.
-* **Embed, without blocks** - The tool is displayed within the existing Moodle window, with just the neavigation controls
+* **Embed, without blocks** - The tool is displayed within the existing Moodle window, with just the navigation controls
         at the top of the page.
 * **New window** - The tool opens in a new window, occupying all the available space.
         Depending on the browser, it will open in a new tab or a popup window.
         It is possible that browsers will prevent the new window from opening.';
-$string['launchoptions'] = 'Launch Options';
+$string['launchoptions'] = 'Launch options';
+$string['leaveblank'] = 'Leave blank if you do not need them';
 $string['lti'] = 'LTI';
 $string['lti:addinstance'] = 'Add new external tool activities';
 $string['lti:addcoursetool'] = 'Add course-specific tool configurations';
@@ -223,19 +246,16 @@ $string['lti:grade'] = 'View grades returned by the external tool';
 $string['lti:manage'] = 'Be an Instructor when the tool is launched';
 $string['lti:requesttooladd'] = 'Request a tool is configured site-wide';
 $string['lti:view'] = 'Launch external tool activities';
-$string['lti_administration'] = 'LTI Administration';
+$string['ltisettings'] = 'LTI settings';
+$string['lti_administration'] = 'Edit preconfigured tool';
 $string['lti_errormsg'] = 'The tool returned the following error message: "{$a}"';
 $string['lti_launch_error'] = 'An error occurred when launching the external tool:';
 $string['lti_launch_error_tool_request'] = '<p>
 To submit a request for an administrator to complete the tool configuration, click <a href="{$a->admin_request_url}" target="_top">here</a>.
 </p>';
-$string['lti_launch_error_unsigned_help'] = '   <p>
-        This error may be a result of a missing consumer key and shared secret for the tool provider.
-    </p>
-    <p>
-        If you have a consumer key and shared secret, you may enter it when editing the external tool instance (make sure advanced options are visible).<br />
-        Alternatively, you may create a course level tool provider configuration <a href="{$a->course_tool_editor}">here</a>.
-    </p>';
+$string['lti_launch_error_unsigned_help'] = '<p>This error may be a result of a missing consumer key and shared secret for the tool provider.</p>
+<p>If you have a consumer key and shared secret, you may enter it when editing the external tool instance (make sure advanced options are visible).</p>
+<p>Alternatively, you may <a href="{$a->course_tool_editor}">create a course level tool provider configuration</a>.</p>';
 $string['lti_tool_request_added'] = 'Tool configuration request successfully submitted. You may need to contact an administrator to complete the tool configuration.';
 $string['lti_tool_request_existing'] = 'A tool configuration for the tool domain has already been submitted.';
 $string['ltiunknownserviceapicall'] = 'LTI unknown service API call.';
@@ -244,7 +264,7 @@ $string['main_admin_help'] = 'External tools allow Moodle users to seamlessly in
 launch protocol, the remote tool will have access to some general information about the launching user. For example,
 the institution name, course id, user id, and other information such as the user\'s name or e-mail address.
 
-Tool types listed on this page are separated into three categories:
+Tools listed on this page are separated into three categories:
 
 * **Active** - These tool providers have been approved and configured by an administrator. They can be used from within any
         course on this Moodle instance. If a consumer key and shared secret are entered, a trust relationship is established
@@ -253,11 +273,15 @@ Tool types listed on this page are separated into three categories:
         Teachers may still use tools from these providers if they have a consumer key and shared secret, or if none is required.
 * **Rejected** - These tools providers are flagged as ones which an administrator has no intention of making available to the entire
         Moodle instance. Teachers may still use tools from these providers if they have a consumer key and shared secret, or if none is required.';
+$string['manage_external_tools'] = 'Manage tools';
+$string['manage_tools'] = 'Manage preconfigured tools';
+$string['manage_tool_proxies'] = 'Manage external tool registrations';
+$string['manuallyaddtype'] = 'Alternatively, you can <a href="{$a}">configure a tool manually</a>.';
 $string['miscellaneous'] = 'Miscellaneous';
 $string['misconfiguredtools'] = 'Misconfigured tool instances were detected';
 $string['missingparameterserror'] = 'The page is misconfigured: "{$a}"';
 $string['module_class_type'] = 'Moodle module type';
-$string['modulename'] = 'External Tool';
+$string['modulename'] = 'External tool';
 $string['modulename_help'] = 'The external tool activity module enables students to interact with learning resources and activities on other web sites. For example, an external tool could provide access to a new activity type or learning materials from a publisher.
 
 To create an external tool activity, a tool provider which supports LTI (Learning Tools Interoperability) is required. A teacher can create an external tool activity or make use of a tool configured by the site administrator.
@@ -268,32 +292,43 @@ External tool activities differ from URL resources in a few ways:
 * External tools support reading, updating, and deleting grades associated with the activity instance
 * External tool configurations create a trust relationship between your site and the tool provider, allowing secure communication between them';
 $string['modulename_link'] = 'mod/lti/view';
-$string['modulenameplural'] = 'External Tools';
+$string['modulename_shortcut_link'] = 'mod/lti/view/custom';
+$string['modulenameplural'] = 'External tools';
 $string['modulenamepluralformatted'] = 'LTI Instances';
+$string['name'] = 'Name';
 $string['never'] = 'Never';
 $string['new_window'] = 'New window';
-$string['no_lti_configured'] = 'There are no active External Tools configured.';
-$string['no_lti_pending'] = 'There are no pending External Tools.';
-$string['no_lti_rejected'] = 'There are no rejected External Tools.';
+$string['no_lti_configured'] = 'There are no active external tools configured.';
+$string['no_lti_pending'] = 'There are no pending external tools.';
+$string['no_lti_rejected'] = 'There are no rejected external tools.';
+$string['no_lti_tools'] = 'There are no external tools configured.';
+$string['no_tp_accepted'] = 'There are no accepted external tool registrations.';
+$string['no_tp_cancelled'] = 'There are no cancelled external tool registrations.';
+$string['no_tp_configured'] = 'There are no unregistered external tool registrations configured.';
+$string['no_tp_pending'] = 'There are no pending external tool registrations.';
+$string['no_tp_rejected'] = 'There are no rejected external tool registrations.';
 $string['noattempts'] = 'No attempts have been made on this tool instance';
-$string['noltis'] = 'There are no lti instances';
+$string['noltis'] = 'There are no external tool instances';
+$string['noprofileservice'] = 'Profile service not found';
 $string['noservers'] = 'No servers found';
-$string['notypes'] = 'There are currently no LTI tools setup in Moodle. Click the Install link above to add some.';
+$string['notypes'] = 'There are currently no LTI tools set up in Moodle. Click the Install link above to add some.';
 $string['noviewusers'] = 'No users were found with permissions to use this tool';
 $string['optionalsettings'] = 'Optional settings';
-$string['organization'] ='Organization details';
-$string['organizationdescr'] ='Organization Description';
-$string['organizationid'] ='Organization ID';
+$string['organization'] = 'Organization details';
+$string['organizationdescr'] = 'Organization description';
+$string['organizationid'] = 'Organization ID';
 $string['organizationid_help'] = 'A unique identifier for this Moodle instance. Typically, the DNS name of the organization is used.
 
 If this field is left blank, the host name of this Moodle site will be used as the default value.';
-$string['organizationurl'] ='Organization URL';
+$string['organizationurl'] = 'Organization URL';
 $string['organizationurl_help'] = 'The base URL of this Moodle instance.
 
 If this field is left blank, a default value will be used based on the site configuration.';
 $string['pagesize'] = 'Submissions shown per page';
-$string['password'] = 'Shared Secret';
-$string['password_admin'] = 'Shared Secret';
+$string['parameter'] = 'Tool parameters';
+$string['parameter_help'] = 'Tool parameters are settings requested to be passed by the tool provider in the accepted tool proxy.';
+$string['password'] = 'Shared secret';
+$string['password_admin'] = 'Shared secret';
 $string['password_admin_help'] = 'The shared secret can be thought of as a password used to authenticate access to the tool. It should be provided
 along with the consumer key from the tool provider.
 
@@ -311,21 +346,29 @@ along with the consumer key from the tool provider.
 Tools which do not require secure communication from Moodle and do not provide additional services (such as grade reporting)
 may not require a shared secret.';
 $string['pending'] = 'Pending';
-$string['pluginadministration'] = 'LTI administration';
-$string['pluginname'] = 'LTI';
-$string['preferheight'] = 'Preferred Height';
-$string['preferwidget'] = 'Prefer Widget Launch';
-$string['preferwidth'] = 'Preferred Width';
+$string['pluginadministration'] = 'External tool administration';
+$string['pluginname'] = 'External tool';
+$string['preferheight'] = 'Preferred height';
+$string['preferwidget'] = 'Prefer widget launch';
+$string['preferwidth'] = 'Preferred width';
 $string['press_to_submit'] = 'Press to launch this activity';
 $string['privacy'] = 'Privacy';
 $string['quickgrade'] = 'Allow quick grading';
 $string['quickgrade_help'] = 'If enabled, multiple tools can be graded on one page. Add grades and comments then click the "Save all my feedback" button to save all changes for that page.';
 $string['redirect'] = 'You will be redirected in few seconds. If you are not, press the button.';
+$string['register'] = 'Register';
+$string['register_warning'] = 'The registration page seems to be taking a while to open. If it does not appear, check that you entered the correct URL in the configuration settings. If Moodle is using https, ensure the tool you are configuring supports https and you are using https in the URL.';
+$string['registertype'] = 'Configure a new external tool registration';
+$string['registration_options'] = 'Registration options';
+$string['registrationname'] = 'Tool provider name';
+$string['registrationname_help'] = 'Enter the name of the tool provider being registered.';
+$string['registrationurl'] = 'Registration URL';
+$string['registrationurl_help'] = 'The registration URL should be available from the tool provider as the location to which registration requests should be sent.';
 $string['reject'] = 'Reject';
 $string['rejected'] = 'Rejected';
 $string['resource'] = 'Resource';
-$string['resourcekey'] = 'Consumer Key';
-$string['resourcekey_admin'] = 'Consumer Key';
+$string['resourcekey'] = 'Consumer key';
+$string['resourcekey_admin'] = 'Consumer key';
 $string['resourcekey_admin_help'] = 'The consumer key can be thought of as a username used to authenticate access to the tool.
 It can be used by the tool provider to uniquely identify the Moodle site from which users launch into the tool.
 
@@ -351,59 +394,92 @@ may not require a resource key.';
 $string['resourceurl'] = 'Resource URL';
 $string['return_to_course'] = 'Click <a href="{$a->link}" target="_top">here</a> to return to the course.';
 $string['saveallfeedback'] = 'Save all my feedback';
-$string['secure_icon_url'] = 'Secure Icon URL';
+$string['search:activity'] = 'External tool - activity information';
+$string['secure_icon_url'] = 'Secure icon URL';
 $string['secure_icon_url_help'] = 'Similar to the icon URL, but used if the user accessing Moodle securely through SSL. The main purpose for this field is to prevent
 the browser from warning the user if the underlying page was accessed over SSL, but requesting to show an unsecure image.';
-$string['secure_launch_url'] = 'Secure Launch URL';
-$string['secure_launch_url_help'] = 'Similar to Launch URL, but used instead of the launch url if high security is required. Moodle will use the
-secure launch URL instead of the launch URL if the Moodle site is accessed through SSL, or if the tool configuration
-is set to always launch through SSL.
+$string['secure_launch_url'] = 'Secure launch URL';
+$string['secure_launch_url_help'] = 'Similar to the launch URL, but used instead of the launch URL if high security is required. Moodle will use the secure launch URL instead of the launch URL if the Moodle site is accessed through SSL, or if the tool configuration is set to always launch through SSL.
 
-The Launch URL may also be set to an https address to force launching through SSL, and this field may be left blank.';
+The launch URL may also be set to an https address to force launching through SSL, and this field may be left blank.';
 $string['send'] = 'Send';
-$string['setupoptions'] = 'Setup Options';
+$string['services'] = 'Services';
+$string['services_help'] = 'Select those services which you wish to offer to the tool provider.  More than one service can be selected.';
+$string['setupoptions'] = 'Set-up options';
 $string['share_email'] = 'Share launcher\'s email with the tool';
 $string['share_email_admin'] = 'Share launcher\'s email with tool';
 $string['share_email_admin_help'] = 'Specify whether the e-mail address of the user launching the tool will be shared with the tool provider.
 The tool provider may need launcher\'s e-mail addresses to distinguish users with the same name in the UI, or send e-mails
 to users based on actions within the tool.';
 $string['share_email_help'] = 'Specify whether the e-mail address of the user launching the tool will be shared with the tool provider.
-The tool provider may need launcher\'s e-mail addresses to distinguish users with the same name, or send e-mails
-to users based on actions within the tool.
 
-Note that this setting may be overriden in the tool configuration.';
+The tool provider may need launcher\'s email addresses to distinguish users with the same name, or send emails to users based on actions within the tool.
+
+Note that this setting may be overridden in the tool configuration.';
 $string['share_name'] = 'Share launcher\'s name with the tool';
 $string['share_name_admin'] = 'Share launcher\'s name with tool';
 $string['share_name_admin_help'] = 'Specify whether the full name of the user launching the tool should be shared with the tool provider.
 The tool provider may need launchers\' names to show meaningful information within the tool.';
 $string['share_name_help'] = 'Specify whether the full name of the user launching the tool should be shared with the tool provider.
+
 The tool provider may need launchers\' names to show meaningful information within the tool.
 
-Note that this setting may be overriden in the tool configuration.';
+Note that this setting may be overridden in the tool configuration.';
 $string['share_roster'] = 'Allow the tool to access this course\'s roster';
 $string['share_roster_admin'] = 'Tool may access course roster';
-$string['share_roster_admin_help'] = 'Specify whether the tool can access the list of users enrolled in courses from which this tool type is launched.';
+$string['share_roster_admin_help'] = 'Specify whether the tool can access the list of users enrolled in courses from which this tool is launched.';
 $string['share_roster_help'] = 'Specify whether the tool can access the list of users enrolled in this course.
 
-Note that this setting may be overriden in the tool configuration.';
-$string['show_in_course'] = 'Show tool type when creating tool instances';
-$string['show_in_course_help'] = 'If selected, this tool configuration will appear in the "External tool type" dropdown when teachers
-configure external tools within courses.
-
-In most cases, this option does not need to be selected. Teachers can use this tool configuration
-based on the Launch URL matching the Tool base URL, which is the preferred method.
-
-The only case in which this option should be selected is if the tool configuration is just intended for single sign on.
-For example, if all launches to the tool provider just take the user to a landing page instead of to a specific resource.';
+Note that this setting may be overridden in the tool configuration.';
+$string['show_in_course_activity_chooser'] = 'Show in activity chooser and as a preconfigured tool';
+$string['show_in_course_lti1'] = 'Tool configuration usage';
+$string['show_in_course_lti1_help'] = 'This tool may be shown in the activity chooser for a teacher to select to add to a course. Alternatively, it may be shown in the preconfigured tool dropdown menu when adding an external tool to a course. A further option is for the tool configuration to only be used if the exact launch URL is entered when adding an external tool to a course.';
+$string['show_in_course_lti2'] = 'Tool configuration usage';
+$string['show_in_course_lti2_help'] = 'This tool can be shown in the activity chooser for a teacher to select to add to a course or in the preconfigured tool dropdown menu when adding an external tool to a course.';
+$string['show_in_course_no'] = 'Do not show; use only when a matching launch URL is entered';
+$string['show_in_course_preconfigured'] = 'Show as preconfigured tool when adding an external tool';
 $string['size'] = 'Size parameters';
 $string['submission'] = 'Submission';
 $string['submissions'] = 'Submissions';
 $string['submissionsfor'] = 'Submissions for {$a}';
-$string['toggle_debug_data'] = 'Toggle Debug Data';
+$string['successfullycreatedtooltype'] = 'Successfully created new tool!';
+$string['subplugintype_ltiresource'] = 'LTI service resource';
+$string['subplugintype_ltiresource_plural'] = 'LTI service resources';
+$string['subplugintype_ltiservice'] = 'LTI service';
+$string['subplugintype_ltiservice_plural'] = 'LTI services';
+$string['subplugintype_ltisource'] = 'LTI source';
+$string['subplugintype_ltisource_plural'] = 'LTI sources';
+$string['toggle_debug_data'] = 'Toggle debug data';
 $string['tool_config_not_found'] = 'Tool configuration not found for this URL.';
-$string['tool_settings'] = 'Tool Settings';
-$string['toolsetup'] = 'External Tool Configuration';
-$string['toolurl'] = 'Tool Base URL';
+$string['tool_settings'] = 'Tool settings';
+$string['tooldescription'] = 'Tool description';
+$string['tooldescription_help'] = 'The description of the tool that will be displayed to teachers in the activity list.
+
+This should describe what the tool is for and what it does and any additional information the teacher may need to know.';
+$string['toolisbeingused'] = 'This tool is being used {$a} times';
+$string['toolisnotbeingused'] = 'This tool has not yet been used';
+$string['toolproxy'] = 'External tool registrations';
+$string['toolproxy_help'] = 'External tool registrations allow Moodle site administrators to configure external tools from a tool proxy obtained from a tool provider supporting LTI 2.0. A registration URL provided by the tool provider is all that is required to initiate the process. The capabilities and services offered to the tool provider are selected when configuring a new registration.
+
+Tool registrations listed on this page are separated into four categories:
+
+* **Configured** - These tool registrations have been set up but the registration process has not yet been started.
+* **Pending** - The registration process for these tool registrations has been started but has not completed. Open and save the settings to move it
+back to the \'Configured\' category.
+* **Accepted** - These tool registrations have been approved; the resources specified in the tool proxy will appear on the preconfigured tools page
+with an initial status of \'Pending\'.
+* **Rejected** - These tool registrations are ones which were rejected during the registration process. Open and save the settings to move it
+back to the \'Configured\' category so the registration process can be restarted.';
+$string['toolproxyregistration'] = 'External tool registration';
+$string['toolregistration'] = 'External tool registration';
+$string['toolsetup'] = 'External tool configuration';
+$string['tooltypes'] = 'Tools';
+$string['tooltypeadded'] = 'Preconfigured tool added';
+$string['tooltypedeleted'] = 'Preconfigured tool deleted';
+$string['tooltypenotdeleted'] = 'Could not delete preconfigured tool';
+$string['tooltypeupdated'] = 'Preconfigured tool updated';
+$string['toolurl'] = 'Tool base URL/cartridge URL';
+$string['toolurlplaceholder'] = 'Tool URL...';
 $string['toolurl_help'] = 'The tool base URL is used to match tool launch URLs to the correct tool configuration. Prefixing the URL with http(s) is optional.
 
 Additionally, the base URL is used as the launch URL if a launch URL is not specified in the external tool instance.
@@ -426,12 +502,20 @@ A base URL of *quiz.tool.com* would match the following:
 * quiz.tool.com
 * quiz.tool.com/take.php?id=10
 
-If two different tool configurations are for the same domain, the most specific match will be used.';
-$string['typename'] = 'Tool Name';
+If two different tool configurations are for the same domain, the most specific match will be used.
+
+You can also insert a cartridge URL if you have one and the details for the tool will be automatically filled.';
+$string['typename'] = 'Tool name';
 $string['typename_help'] = 'The tool name is used to identify the tool provider within Moodle. The name entered will be visible
 to teachers when adding external tools within courses.';
 $string['types'] = 'Types';
+$string['unabletocreatetooltype'] = 'Unable to create tool';
+$string['unabletofindtooltype'] = 'Unable to find tool for {$a->id}';
+$string['unknownstate'] = 'Unknown state';
 $string['update'] = 'Update';
+$string['useraccountinformation'] = 'User account information';
+$string['userpersonalinformation'] = 'User personal information';
+$string['using_tool_cartridge'] = 'Using tool cartridge';
 $string['using_tool_configuration'] = 'Using tool configuration: ';
 $string['validurl'] = 'A valid URL must start with http(s)://';
 $string['viewsubmissions'] = 'View submissions and grading screen';
